#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: boxes
version: 0.1.4
id: boxes-0.1.4-97f2f1e73315b28e44166cef48ce34c5
key: boxes_4R0jhlpEOHjDkEW4u6wUoL
license: BSD3
maintainer: David Feuer <David.Feuer@gmail.com>
synopsis: 2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.
category: Text
author: Brent Yorgey
exposed: True
exposed-modules:
    Text.PrettyPrint.Boxes
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/boxes-0.1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/boxes-0.1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/boxes-0.1.4
hs-libraries: HSboxes-0.1.4-4R0jhlpEOHjDkEW4u6wUoL
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    split-0.2.3.1-720861915f5bd1738e9c1363195cfb8f
haddock-interfaces: /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html: /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
